<?php
/*
Plugin Name: Flickr Gallery
Plugin URI: http://co.deme.me/projects/flickr-gallery/
Description: Use easy shortcodes to insert Flickr galleries and photos (and videos) in your blog.
Author: Dan Coulter
Version: 1.0.1
Author URI: http://dancoulter.com/
*/ 

/**
 * LICENSE
 * This file is part of Flickr Gallery.
 *
 * Flickr Gallery is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @package    flickr-gallery
 * @author     Dan Coulter <dan@dancoulter.com>
 * @copyright  Copyright 2009 Dan Coulter
 * @license    http://www.gnu.org/licenses/gpl.txt GPL 2.0
 * @version    1.0.1
 * @link       http://co.deme.me/projects/flickr-gallery/
 */

if ( !defined('WP_CONTENT_URL') )
	define( 'WP_CONTENT_URL', get_option('siteurl') . '/wp-content');
if ( !defined('WP_CONTENT_DIR') )
	define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' );
	
class DC_FlickrGallery {
	/**
	 * Return the filesystem path that the plugin lives in.
	 *
	 * @return string
	 */
	function getPath() {
		return dirname(__FILE__) . '/';
	}
	
	/**
	 * Returns the URL of the plugin's folder.
	 *
	 * @return string
	 */
	function getURL() {
		return WP_CONTENT_URL.'/plugins/'.basename(dirname(__FILE__)) . '/';
	}
	
	/**
	 * Initializes the phpFlickr object.  Called on WP's init hook.
	 *
	 */
    function init() {
		if ( get_option('fg-API-key') ) {
			global $phpFlickr;
			include_once 'phpFlickr.php';
			$phpFlickr = new phpFlickr(get_option('fg-API-key'), get_option('fg-secret') ? get_option('fg-secret') : null);
			if ( get_option('fg-db-cache') == 1 ) {
				$phpFlickr->enableCache('custom', array(array('DC_FlickrGallery', 'cache_get'), array('DC_FlickrGallery', 'cache_set')));
			}
			wp_enqueue_script('jquery-ui-tabs');			
			//wp_enqueue_script('jquery-color');			
			wp_enqueue_script('jquery-flightbox', DC_FlickrGallery::getURL() . 'flightbox/jquery.flightbox.js', array(), rand());			
			wp_enqueue_style('jquery-flightbox', DC_FlickrGallery::getURL() . 'flightbox/jquery.flightbox.css', array(), rand());			
		}
		
		
		if ( $_POST['action'] == 'update' && $_POST['fg-API-key'] && substr($_POST['page_options'], 0, 20) == 'fg-API-key,fg-secret' ) {
			global $wpdb;
			include_once 'phpFlickr.php';
			$phpFlickr = new phpFlickr($_POST['fg-API-key'], (empty($_POST['fg-secret']) ? null : $_POST['fg-secret']));
			switch ( $_POST['fg-user_id-type'] ) {
				case 'name':
					$user = $phpFlickr->people_findByUsername($_POST['fg-user_id']);
					$_POST['fg-user_id'] = $user['id'];
					break;
				case 'email':
					$user = $phpFlickr->people_findByEmail($_POST['fg-user_id']);
					$_POST['fg-user_id'] = $user['id'];
					break;
				case 'url':
					$user = $phpFlickr->urls_lookupUser($_POST['fg-user_id']);
					$_POST['fg-user_id'] = $user['id'];
					break;
			}
			
			if ( $_POST['fg-db-cache'] == 1 ) {
				if ( isset($wpdb->charset) && !empty($wpdb->charset) ) {
					$charset = ' DEFAULT CHARSET=' . $wpdb->charset;
				} elseif ( defined(DB_CHARSET) && DB_CHARSET != '' ) {
					$charset = ' DEFAULT CHARSET=' . DB_CHARSET;
				} else {
					$charset = '';
				}

				$query = '
					CREATE TABLE IF NOT EXISTS `' . $wpdb->prefix . 'phpflickr_cache` (
						`request` CHAR( 35 ) NOT NULL ,
						`response` MEDIUMTEXT NOT NULL ,
						`expiration` DATETIME NOT NULL ,
						PRIMARY KEY ( `request` )
					)  ' . $charset . '
				';
				$wpdb->query($query);
			}
			
			if ( empty($_POST['fg-token']) ) {
				$token = $phpFlickr->auth_getToken($_POST['fg-frob']);
				$_POST['fg-token'] = $token['token'];
			}
		}
		
		if ( $_GET['action'] == 'flickr-gallery-photoset' ) {
			DC_FlickrGallery::ajax_photoset($_GET['id'], $_GET['page']);
		}
    }
	
	function cache_get($key) {
		global $wpdb;
		$result = $wpdb->get_row('
			SELECT 
				* 
			FROM 
				`' . $wpdb->prefix . 'phpflickr_cache` 
			WHERE 
				request = "' . $wpdb->escape($key) . '" AND
				expiration >= NOW()
		');
		if ( is_null($result) ) return false;
		return $result->response;
	}
	
	function cache_set($key, $value, $expire) {
		global $wpdb;
		$query = '
			INSERT INTO `' . $wpdb->prefix . 'phpflickr_cache`
				(
					request, 
					response, 
					expiration
				)
			VALUES
				(
					"' . $wpdb->escape($key) . '", 
					"' . $wpdb->escape($value) . '", 
					FROM_UNIXTIME(' . (time() + (int) $expire) . ')
				)
			ON DUPLICATE KEY UPDATE 
				response = VALUES(response),
				expiration = VALUES(expiration)
			
		';
		$wpdb->query($query);
	}

    /**
     * Handles the [flickr-gallery] shortcode
     *
     * @param array $attr
     * @param string $content
     * @return string
     */
    function gallery($attr, $content = '') {
		if ( get_option('fg-API-key') ) {
			$id = substr(md5(microtime()), 0, 8);
			global $phpFlickr;
			$attr = array_merge(array(
				'photoset' => null,
				'sort' => null,
				'tags' => null,
				'mode' => null,
				'tag_mode' => 'any',
				'user_id' => (isset($attr['mode']) && $attr['mode'] == 'search') ? null : get_option('fg-user_id'),
				'per_page' => get_option('fg-per_page'),
			), (is_array($attr) ? $attr : array()));
			
			ob_start();
			switch ($attr['mode']) {
				case 'photoset' :
					$photos = $phpFlickr->photosets_getPhotos($attr['photoset'], null, null, $attr['per_page']);
					$url = DC_FlickrGallery::get_photo_url($photos['owner']);
					if ( count($photos['photo']) ) {
						?>
							<div class="flickr-gallery photoset">
								<?php foreach ( $photos['photo'] as $photo ) : ?>
									<div class="flickr-thumb">
										<a href="<?php echo $url . $photo['id'] ?>"><img title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" /></a>
									</div>
								<?php endforeach; ?>
								<div class="clear"></div>
								<?php if ( get_option('fg-credit-link') ) : ?>
									<div class="clear alignright"><?php _e('Powered by <a href="http://co.deme.me/projects/flickr-gallery/">Flickr Gallery</a>') ?></div>
								<?php endif; ?>
							</div>
						<?php
					}
					break;
				case 'tag' :
					$url = DC_FlickrGallery::get_photo_url($attr['user_id']);
					$photos = $phpFlickr->photos_search(array(
						'per_page' => $attr['per_page'],
						'user_id' => $attr['user_id'],
						'tags' => $attr['tags'],
						'sort' => $attr['sort'],
						'tag_mode' => $attr['tag_mode'],
					));
					if ( count($photos['photo']) ) {
						?>
							<div class="flickr-gallery tag">
								<?php foreach ( $photos['photo'] as $photo ) : ?>
									<div class="flickr-thumb">
										<a href="<?php echo $url . $photo['id'] ?>"><img title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" /></a>
									</div>
								<?php endforeach; ?>
								<div class="clear"></div>
								<?php if ( get_option('fg-credit-link') ) : ?>
									<div class="clear alignright"><?php _e('Powered by <a href="http://co.deme.me/projects/flickr-gallery/">Flickr Gallery</a>') ?></div>
								<?php endif; ?>
							</div>
						<?php
					}
					break;
				case 'recent' :
					$args = $attr;
					unset($args['mode']);
					$photos = $phpFlickr->photos_search($args);
					$url = DC_FlickrGallery::get_photo_url($attr['user_id']);
					if ( count($photos['photo']) ) {
						?>
							<div class="flickr-gallery search">
								<?php foreach ( $photos['photo'] as $photo ) : ?>
									<div class="flickr-thumb">
										<a href="<?php echo $url . '/' . $photo['id'] ?>"><img title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" /></a>
									</div>
								<?php endforeach; ?>
								<div class="clear"></div>
								<?php if ( get_option('fg-credit-link') ) : ?>
									<div class="clear alignright"><?php _e('Powered by <a href="http://co.deme.me/projects/flickr-gallery/">Flickr Gallery</a>') ?></div>
								<?php endif; ?>
							</div>
						<?php
					}
					break;
				case 'interesting' :
					$args = $attr;
					unset($args['mode']);
					$args['sort'] = "interestingness-desc";
					$photos = $phpFlickr->photos_search($args);
					$url = DC_FlickrGallery::get_photo_url($attr['user_id']);
					if ( count($photos['photo']) ) {
						?>
							<div class="flickr-gallery search">
								<?php foreach ( $photos['photo'] as $photo ) : ?>
									<div class="flickr-thumb">
										<a href="<?php echo $url . $photo['id'] ?>"><img title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" /></a>
									</div>
								<?php endforeach; ?>
								<div class="clear"></div>
								<?php if ( get_option('fg-credit-link') ) : ?>
									<div class="clear alignright">Powered by <a href="http://co.deme.me/projects/flickr-gallery/">Flickr Gallery</a></div>
								<?php endif; ?>
							</div>
						<?php
					}
					break;
				case 'search' :
					$args = $attr;
					unset($args['mode']);
					$photos = $phpFlickr->photos_search($args);
					$url = DC_FlickrGallery::get_photo_url();
					if ( count($photos['photo']) ) {
						?>
							<div class="flickr-gallery search">
								<?php foreach ( $photos['photo'] as $photo ) : ?>
									<div class="flickr-thumb">
										<a href="<?php echo $url . $photo['id'] ?>"><img title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" /></a>
									</div>
								<?php endforeach; ?>
								<div class="clear"></div>
								<?php if ( get_option('fg-credit-link') ) : ?>
									<div class="clear alignright"><?php _e('Powered by <a href="http://co.deme.me/projects/flickr-gallery/">Flickr Gallery</a>') ?></div>
								<?php endif; ?>
							</div>
						<?php
					}
					break;
				default :
					if ( !empty($attr['user_id']) ) {
						$url = DC_FlickrGallery::get_photo_url($attr['user_id']);
						$tabs = apply_filters('flickr_gallery_tabs', array(
							array('id'=>'photostream', 'name'=>'Photostream'),
							array('id'=>'sets', 'name'=>'Photosets'),
							array('id'=>'interesting', 'name'=>'Most Interesting'),
						));
						?>
							<div id="gallery-<?php echo $id ?>" class="flickr-gallery">
								<ol>
									<?php foreach ( $tabs as $tab ) : ?>
										<li><a href="#<?php echo $tab['id'] ?>"><?php echo $tab['name'] ?></a></li>
									<?php endforeach ?>
								</ol>
								<?php foreach ( $tabs as $tab ) : ?>
									<?php if ( $tab['id'] == 'photostream' && !isset($tab['callback']) ) : ?>
										<div id="photostream">
											<?php 
												$photos = $phpFlickr->photos_search(array(
													'user_id' => $attr['user_id'], 
													'per_page' => $attr['per_page'],
													'extras' => 'media',
												))
											?>
											<div class="flickr-photos">
												<?php foreach ( $photos['photo'] as $photo ) : ?>
													<div class="flickr-thumb">
														<a href="<?php echo $url . $photo['id'] ?>"><img class="<?php echo $photo['media'] ?>" title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" /></a>
													</div>
												<?php endforeach; ?>
											</div>
											<div class="clear"></div>
										</div>
									<?php elseif ( $tab['id'] == 'sets' && !isset($tab['callback']) ) : ?>
										<div id="sets">
											<?php
												$set_url = $url == 'http://flickr.com/photo.gne?id=' ? 'http://flickr.com/photos/' . $attr['user_id'] . '/sets/' : $url . 'sets/';
												$sets = $phpFlickr->photosets_getList($attr['user_id']);
												foreach( $sets['photoset'] as $set ) :
													?>
														<div class="flickr-set" id="set-<?php echo $set['id'] ?>">
															<div class="flickr-set-thumb">
																<a href="<?php echo $set_url . $set['id']; ?>/">
																	<img title="<?php echo str_replace("\"", "\\\"", $set['title']) ?>" alt="<?php echo str_replace("\"", "\\\"", $set['title']) ?>" class="flickr-thumb" src="http://farm<?php echo $set['farm']; ?>.static.flickr.com/<?php echo $set['server']; ?>/<?php echo $set['primary']; ?>_<?php echo $set['secret']; ?>_s.jpg" /></a>
															</div>
															<div class="flickr-set-meta">
																<div class="flickr-set-title"><a href="<?php echo $url ?>sets/<?php echo $set['id']; ?>/"><?php echo $set['title']; ?></a> (<?php echo $set['photos']; ?> photos)</div>
																<div class="flickr-set-description"><?php echo $set['description']; ?></div>
															</div>
															<div class="flickr-set-display">
																<?php _e('Loading...', 'flickr-gallery') ?>
															</div>
															<div class="clear"></div>
														</div>
													<?php
												endforeach;
											?>
										</div>
										
										<script type="text/javascript">
											//<!--
											(function($){
												$(".flickr-set .flickr-set-thumb a, .flickr-set .flickr-set-title a").click(function(){
													var $set = $(this).parents(".flickr-set");
													var id = $set.attr("id").split("-")[1];
													var $display = $set.children(".flickr-set-display");
													if ( $display.css("display") == "none" ) {
														$display.show().html("Loading...");
														$display.load("<?php echo get_bloginfo('wpurl') ?>?action=flickr-gallery-photoset&page=1&id=" + id, {}, function(){
															$display.find(".flickr-thumb img").flightbox();
														});
													} else {
														$display.hide();
													}
													
													return false;
												});
											})(jQuery);
											//-->
										</script>
									<?php elseif ( $tab['id'] == 'interesting' && !isset($tab['callback']) ) : ?>
										<div id="interesting">
											<?php
												$photos = $phpFlickr->photos_search(array(
													'user_id' => $attr['user_id'],
													'per_page' => $attr['per_page'],
													'sort' => 'interestingness-desc',
													'extras' => 'media',
												));
											?>
											<div class="flickr-photos">
												<?php foreach ( $photos['photo'] as $photo ) : ?>
													<div class="flickr-thumb">
														<a href="<?php echo $url . $photo['id'] ?>"><img class="<?php echo $photo['media'] ?>" title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" /></a>
													</div>
												<?php endforeach; ?>
											</div>
											<div class="clear"></div>
										</div>
									<?php elseif ( isset($tab['callback']) ) : ?>
										<div id="<?php echo $tab['id'] ?>">
											<?php call_user_func($tab['callback']); ?>
											<div class="clear"></div>
										</div>
									<?php endif ?>
								<?php endforeach ?>
								<?php if ( get_option('fg-credit-link') ) : ?>
									<div class="clear alignright"><?php _e('Powered by <a href="http://co.deme.me/projects/flickr-gallery/">Flickr Gallery</a>') ?></div>
								<?php endif; ?>
							</div>
							<script type="text/javascript">
								jQuery("#gallery-<?php echo $id ?> > ol").tabs();
								jQuery('#sets .flickr-set:not(:first)').css({borderTop:"1px solid #D3D3D3", paddingTop: ".5em"});
							</script>
						<?php
					}
					break;
				
			}
			if ( get_option('fg-flightbox') === false || get_option('fg-flightbox') ) {
				?>
					<script type="text/javascript">
						jQuery(".flickr-thumb img").flightbox();
					</script>
				<?php
			}
			$result = ob_get_clean();
			return $result;
		}
    }
	
    /**
     * Handles the [flickr][/flickr] shortcode
     *
     * @param array $attr
     * @param string $content
     * @return string
     */
    function image($attr, $content) {
		if ( get_option('fg-API-key') ) {
			global $phpFlickr;
			$attr = shortcode_atts(array(
				'size' => 'medium',
				'float' => 'none',
				'height' => null,
				'width' => null,
			), $attr);

			if ( ereg( '/([0-9]+)/$', $content, $match) ) {
				$id = $match[1];
			} else {
				$id = $content;
			}

			$photo = $phpFlickr->photos_getInfo($id);
			
			if ( isset($photo['id']) ) {
				$url = $phpFlickr->urls_getUserPhotos($photo['owner']['nsid']);
				ob_start();
				if ( 'video' == $photo['media'] ) {
					$sizes = $phpFlickr->photos_getSizes($photo['id']);
					foreach ( $sizes as $size ) {
						if ( $size['label'] == 'Video Player' ) {
							break;
						}
					}
					
					if ( is_null($attr['height']) ) $attr['height'] = $size['height'];
					if ( is_null($attr['width']) ) $attr['width'] = $size['width'];
					?>
						<div class="flickr-gallery video <?php echo $attr['float'] ?>">
							<object type="application/x-shockwave-flash" wmode="opaque" width="<?php echo $attr['width'] ?>" height="<?php echo $attr['height'] ?>" data="<?php echo urlencode($size['source']) ?>" classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000">
								<param name="movie" value="<?php echo urlencode($size['source']) ?>"></param>
								<param name="bgcolor" value="#000000"></param>
								<param name="allowFullScreen" value="true"></param>
								<param name="wmode" value="opaque" />
								<embed type="application/x-shockwave-flash" src="<?php echo $size['source'] ?>" bgcolor="#000000" allowfullscreen="true" flashvars="intl_lang=en-us&amp;photo_secret=<?php echo $photo['secret'] ?>&amp;photo_id=<?php echo $photo['id'] ?>" height="<?php echo $attr['height'] ?>" width="<?php echo $attr['width'] ?>" wmode="opaque"></embed>
							</object>
						</div>
					<?php
				} else {
					?>
						<div class="flickr-gallery image <?php echo $attr['float'] ?>"><a href="<?php echo $url . $photo['id'] ?>"><img title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, $attr['size']) ?>" /></a></div>
					<?php
				}
				return ob_get_clean();
			} else {
				return '';
			}
		}
		
    }
	
    /**
     * Sets up the settings page
     *
     */
	function add_settings_page() {
		load_plugin_textdomain('flickr-gallery', DC_FlickrGallery::getPath());
		add_options_page(__('Flickr Gallery', 'flickr-gallery'), __('Flickr Gallery', 'flickr-gallery'), 8, __FILE__, array('DC_FlickrGallery', 'settings_page'));	
	}
	 
	/**
	 * Generates the settings page
	 *
	 */
	function settings_page() {
		global $phpFlickr;
		?>
			<div class="wrap">
				<h2><?php _e('Flickr Gallery', 'flickr-gallery') ?></h2>
				<form method="post" action="options.php">
					<input type="hidden" name="action" value="update" />
					<?php wp_nonce_field('update-options'); ?>
					<input type="hidden" name="page_options" value="fg-API-key,fg-secret,fg-token,fg-user_id,fg-per_page,fg-db-cache,fg-credit-link,fg-flightbox" />
					<p>
						<?php _e('Flickr <a href="http://www.flickr.com/services/api/keys/">API Key</a>:', 'flickr-gallery') ?>
						<input type="text" name="fg-API-key" value="<?php echo get_option('fg-API-key'); ?>" />
					</p>
					<p>
						<label for="fg-db-cache"><?php _e('Enable database result caching:', 'flickr-gallery') ?></label>
						<input id="fg-db-cache" type="checkbox" value="1" name="fg-db-cache" <?php echo get_option('fg-db-cache') ? 'checked="checked"' : '' ?> />
					</p>
					<p>
						<?php _e('Flickr User ID:', 'flickr-gallery') ?>
						<input type="text" name="fg-user_id" id="fg-user_id" value="<?php echo get_option('fg-user_id'); ?>" />
						<select name="fg-user_id-type" id="fg-user_id-type">
							<option value="id"><?php _e('User ID (12345678@N00)', 'flickr-gallery'); ?></option>
							<option value="name"><?php _e('User Name (the name displayed at the top of your photopage)', 'flickr-gallery'); ?></option>
							<option value="email"><?php _e('Email Address', 'flickr-gallery'); ?></option>
							<option value="url"><?php _e('Flickr photopage URL', 'flickr-gallery'); ?></option>
						</select>
						<?php 
							if ( get_option('fg-token') ) {
								$_token = $phpFlickr->auth_checkToken();
								if ( $_token !== false ) {
									echo '<button class="button" id="fg-use-authed-user">' . __('Use your authed user', 'flickr-gallery') . '</button>';
								}
							}
						?>
					</p>
					<p>
						<?php _e('Number of photos to display:', 'flickr-gallery') ?>
						<input type="text" name="fg-per_page" value="<?php echo get_option('fg-per_page') ? get_option('fg-per_page') : 60; ?>" />
					</p>
					<p>
						<label for="fg-flightbox"><?php _e('Use a lightbox to display your photos:', 'flickr-gallery') ?></label>
						<input id="fg-flightbox" type="checkbox" value="1" name="fg-flightbox" <?php echo ( get_option('fg-flightbox') === false || get_option('fg-flightbox') ) ? 'checked="checked"' : '' ?> />
					</p>
					<p><strong><?php _e("If you want the plugin to include private photos or photos in private groups, you will need to fill in the following fields.  Leave them blank otherwise.  Also, you will need to make sure that your API key's authentication type is set to Desktop at Flickr.", 'flickr-gallery') ?></strong></p>
					<p>
						<?php _e('Flickr API Secret:', 'flickr-gallery') ?>
						<input type="text" name="fg-secret" value="<?php echo get_option('fg-secret'); ?>" />
					</p>
					<p>
						<?php if ( get_option('fg-secret') && get_option('fg-api-key') ) : ?>
							<?php printf(__('Authentication Token (<a target="_blank" id="auth-link" href="%s">generate</a>):', 'flickr-gallery'), $phpFlickr->desktop_auth()) ?>
							<input type="hidden" name="fg-frob" id="fg-frob" value="<?php echo $phpFlickr->parsed_response['frob'] ?>" />
						<?php else : ?>
							<?php printf(__('Authentication Token (<em>Save your API Key and Secret to generate</em>):', 'flickr-gallery'), 'http://flickr.com') ?>
						<?php endif; ?>
						<input type="text" id="fg-token" name="fg-token" value="<?php echo get_option('fg-token'); ?>" />
					</p>
					<p><?php _e("<strong>A quick note about private photos...</strong> Because of the Flickr TOS, all images in this plugin link back to the photo page.  If an image is private (or marked for friends and family only) some people clicking through might get a message that they don't have permissions to see the photo.  For now, that's just the way it has to be (until I add on a few other cool features).", 'flickr-gallery') ?></p>

					<p>
						<label for="fg-credit-link"><?php _e('Show a small credit link for the plugin under your galleries:', 'flickr-gallery') ?></label>
						<input id="fg-credit-link" type="checkbox" value="1" name="fg-credit-link" <?php echo get_option('fg-credit-link') ? 'checked="checked"' : '' ?> />
					</p>

					<p class="submit">
						<input type="submit" name="Submit" value="<?php _e('Save Changes', 'flickr-gallery') ?>" />
					</p>
				</form>
				<div id="flickr-test"><!---->
					<?php if ( isset($phpFlickr) && get_option('fg-user_id') ) : ?>
						<?php 
							$photos = $phpFlickr->people_getPublicPhotos(get_option('fg-user_id'), null, 8);
							if ( $photos === false ) {
								_e('The Flickr API has returned the following error message.', 'flickr-gallery');
								echo "<br />" . $phpFlickr->getErrorCode() . ': ' .$phpFlickr->getErrorMsg();
							} else {
								?>
									<p><?php _e("Some of your Flickr photos should appear below.", 'flickr-gallery'); ?></p>
									<div>
										<?php foreach ( $photos['photo'] as $photo ) : ?>
											<a style="border: 0px; padding-right: 10px;" href="http://flickr.com/photos/<?php echo get_option('fg-user_id') ?>/<?php echo $photo['id'] ?>">
												<img src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" alt="<?php echo addslashes($photo['title']) ?>" title="<?php echo addslashes($photo['title']) ?>: <?php echo addslashes($photo['description']) ?>" />
											</a>
										<?php endforeach; ?>
									</div>
								<?php
							}
						?>
						
					
					<?php else : ?>
						<?php _e('When you enter your API key and Flickr User ID, your photos should appear here.', 'flickr-gallery') ?>
					<?php endif; ?>
				</div>
				<script type="text/javascript">
					jQuery("#auth-link").click(function(){
						jQuery(this).before("<?php _e("Go ahead and save this form when you've authorized your API Key", 'flickr-gallery') ?>").remove();
						jQuery("#fg-token").val("");
					});
					
					<?php if ( $_token !== false ) : ?>
						jQuery("#fg-use-authed-user").click(function(){
							jQuery("#fg-user_id").val("<?php echo $_token['user']['nsid'] ?>");
							jQuery("#fg-user_id-type").val("id");
							return false;
						});
					<?php endif; ?>
				</script>
			</div>
		<?php
	}
	
	/**
	 * Inserts the CSS for the plugin into the theme's <head>
	 *
	 */
	function head() {
		?>
			<link href="<?php echo DC_FlickrGallery::getURL() ?>flickr-gallery.css" media="screen" rel="stylesheet" type="text/css" />
		<?php
	}
	
	/**
	 * Inserts the settings link on the plugin's page
	 *
	 */
	function settings_link($links) {
		$settings_link = '<a href="options-general.php?page=' . plugin_basename(__FILE__) . '">' . __('Settings', 'flickr-gallery') . '</a>'; 
		array_unshift( $links, $settings_link ); 
		return $links; 
	}
	
	function get_photo_url($nsid = null) {
		if ( is_null($nsid) ) return 'http://flickr.com/photo.gne?id=';
		
		global $phpFlickr;
		$url = $phpFlickr->urls_getUserPhotos($nsid);
		return empty($url) ? 'http://flickr.com/photo.gne?id=' : $url;
	}
	
	function ajax_photoset($id, $page = 1) {
		global $phpFlickr;
		$set = $phpFlickr->photosets_getPhotos($id, null, null, get_option('fg-per_page'), $page);
		$url = $phpFlickr->urls_getUserPhotos($set['owner']);
		?>
			<div style="clear: both;"><a href="<?php echo $url . 'sets/' . $id ?>"><?php 
				if ( $set['pages'] == 1 ) {
					_e('View this set on Flickr', 'flickr-gallery');
				} else {
					_e('View more photos on Flickr', 'flickr-gallery');
				}
			?></a></div>
			<div class="flickr-photos">
				<?php foreach ( $set['photo'] as $photo ) : ?>
						<div class="flickr-thumb">
							<a href="<?php echo $url . $photo['id'] ?>"><img class="<?php echo $photo['media'] ?>" title="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" alt="<?php echo str_replace("\"", "\\\"", $photo['title']) ?>" src="<?php echo $phpFlickr->buildPhotoURL($photo, 'square') ?>" /></a>
						</div>
				<?php endforeach ?>
			</div>
		<?php
		exit;
	}

}

add_shortcode('flickr-gallery', array('DC_FlickrGallery', 'gallery'));
add_shortcode('flickr', array('DC_FlickrGallery', 'image'));

add_action('admin_menu', array('DC_FlickrGallery', 'add_settings_page'));
add_action('init', array('DC_FlickrGallery', 'init'));
add_action('wp_head', array('DC_FlickrGallery', 'head'));

add_filter("plugin_action_links_" . plugin_basename(__FILE__), array('DC_FlickrGallery', 'settings_link') ); 

add_action('the_content', 'dtc_test', 100);
function dtc_test($text) {
	return str_replace(']]&gt;', ']]>', $text);
}



?>
